aleimi
======


.. list-table::
    :widths: 12 35

    * - **Documentation**
      - |docs|
    * - **Tutorials**
      - |binder|
    * - **CI/CD**
      - |tests| |codecov| |codacy|
    * - **Build**
      - |pypi-version|
    * - **Source Code**
      - |github|
    * - **Python Versions**
      - |pyversions|
    * - **Dependencies**
      - |rdkit| |mopac|
    * - **License**
      - |license|
    * - **Downloads**
      - |downloads|


Description
-----------

``aleimi`` is a versatile Python package designed for performing conformational analysis of small molecules.
The package utilizes a range of theories, including classical mechanics, semiempirical, and high-level quantum mechanics,
to provide comprehensive and accurate analyses of molecular conformations.

.. warning::

    Please be aware that ``aleimi`` is currently undergoing heavy development, which may result in significant changes to the codebase without prior notice.
    Therefore, we advise caution when using the package. We strongly recommend that you always pin your version of the package to ensure that your pipelines are not broken.

You can try it out prior to any installation on `Binder <https://mybinder.org/v2/git/https%3A%2F%2Fgithub.com%2Fale94mleon%2Faleimi/main?labpath=docs%2Fnotebooks%2Fquickstart.ipynb>`__.

Documentation
-------------

The installation instructions, documentation and tutorials can be found online on `ReadTheDocs <https://aleimi.readthedocs.io/en/latest/>`_.

Issues
------

If you have found a bug, please open an issue on the `GitHub Issues <https://github.com/ale94mleon/aleimi/issues>`_.

Discussion
----------

If you have questions on how to use ``aleimi``, or if you want to give feedback or share ideas and new features, please head to the `GitHub Discussions <https://github.com/ale94mleon/aleimi/discussions>`_.

Citing aleimi
-------------

Please refer to the `citation page <https://aleimi.readthedocs.io/en/latest/source/citations.html>`__ on the documentation.



..  |docs|  image:: https://readthedocs.org/projects/aleimi/badge/?version=latest
    :target: https://aleimi.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation
..  |binder| image:: https://mybinder.org/badge_logo.svg
    :target: https://mybinder.org/v2/git/https%3A%2F%2Fgithub.com%2Fale94mleon%2Faleimi/main?labpath=docs%2Fnotebooks%2Fquickstart.ipynb
    :alt: binder
..  |tests| image:: https://github.com/ale94mleon/aleimi/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/ale94mleon/aleimi/actions/workflows/tests.yml
    :alt: tests
..  |codecov| image:: https://codecov.io/gh/ale94mleon/aleimi/branch/main/graph/badge.svg?token=j5uUpLUJ4Z
    :target: https://codecov.io/gh/ale94mleon/aleimi
    :alt: codecov
..  |codacy| image:: https://app.codacy.com/project/badge/Grade/6a8ded08c0eb45d493b1db0c60affe13
    :target: https://app.codacy.com/gh/ale94mleon/aleimi/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade
    :alt: codacy
..  |pypi-version|  image:: https://img.shields.io/pypi/v/aleimi.svg
    :target: https://pypi.python.org/pypi/aleimi/
    :alt: pypi-version
..  |github|    image:: https://badgen.net/badge/icon/github?icon=github&label
    :target: https://github.com/ale94mleon/aleimi
    :alt: GitHub-Repo
..  |pyversions|    image:: https://img.shields.io/pypi/pyversions/aleimi.svg
    :target: https://pypi.python.org/pypi/aleimi/
..  |rdkit| image:: https://img.shields.io/static/v1?label=Powered%20by&message=RDKit&color=3838ff&style=flat&logo=data:image/x-icon;base64, 
    :target: https://www.rdkit.org/docs/index.html
    :alt: rdkit
..  |mopac| image:: https://img.shields.io/static/v1?label=Powered%20by&message=mopac&color=6858ff&style=flat
    :target: https://github.com/openmopac/mopac
    :alt: mopac
..  |license| image:: https://badgen.net/pypi/license/aleimi/
    :target: https://pypi.python.org/pypi/aleimi/
    :alt: license
..  |downloads| image:: https://static.pepy.tech/personalized-badge/aleimi?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads
    :target: https://pepy.tech/project/aleimi
    :alt: download